@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use DateTime::Format::RFC3339;
-use Params::CheckCompiler qw( compile );
+use Params::ValidationCompiler qw( compile );
 use Scalar::Util qw( blessed );
 use WebService::PivotalTracker::Client;
 use WebService::PivotalTracker::Me;
@@ -258,7 +258,7 @@ WebService::PivotalTracker - Perl library for the Pivotal Tracker REST API
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
