@@ -4,9 +4,9 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
-use Params::CheckCompiler qw( compile );
+use Params::ValidationCompiler qw( compile );
 use WebService::PivotalTracker::PropertyAttributes;
 use WebService::PivotalTracker::Types
     qw( ArrayRef Bool DateTimeObject NonEmptyStr PositiveInt );
